==> scupy-0.0.4.tar.gz: scupy-0.0.4/scupy/tasks.py <==
from task_struct import Task
from typing import Union
import json
import pathlib


from typing import Dict, Any
import json

class Task:
    class Fields:
        ID = "id"
        UNIT = "unit"
        TASK_TEXT = "task_text"
        TASK_SOLUTION_CODE_ANALYTICS = "task_solution_code_analytics"
        TASK_SOLUTION_CODE = "task_solution_code"

    def __init__(self, id: int = 0, unit: str = "test", task_text: str = "нет", task_solution_code_analytics: str = "нет", task_solution_code: str = "нет"):
        self.id = id
        self.unit = unit
        self.task_text = task_text
        self.task_solution_code_analytics = task_solution_code_analytics
        self.task_solution_code = task_solution_code

    def deserialize(self, data: Dict[Any]) -> 'Task':
        return Task(
            id=data.get(Task.Fields.ID),
            unit=data.get(Task.Fields.UNIT),
            task_text=data.get(Task.Fields.TASK_TEXT),
            task_solution_code_analytics=data.get(Task.Fields.TASK_SOLUTION_CODE_ANALYTICS),
            task_solution_code=data.get(Task.Fields.TASK_SOLUTION_CODE)
        )


    @staticmethod
    def load_all_tasks():
        all_tasks = []
        with open(pathlib.Path(pathlib.Path(pathlib.Path.cwd(), "tasks_base.json"))) as f:
            for row in f:
                all_tasks.append(Task.deserialize(json.loads(row)))
        return all_tasks


    @staticmethod
    def get_task_by_id(id: int) -> Union[Task, str]:
        all_tasks = Task.load_all_tasks()
        for task in all_tasks:
            if task.id == id:
                return task
        return "NO TASK WITH THAT WORD, CHECK IT"

    @staticmethod
    def find_by_word(word: str):
        all_tasks = Task.load_all_tasks()
        for task in all_tasks:
            task_words = task.task_text.split(" ")
            task_words = [w.lower() for w in task_words]
            if word in task_words:
                print(task.id, task.task_text)

==> scupy-0.0.7.tar.gz: scupy-0.0.7/scupy/tasks.py <==
from typing import Union
import json
import pathlib
from typing import Dict, Any
import json

class Task:
    class Fields:
        ID = "id"
        UNIT = "unit"
        TASK_TEXT = "task_text"
        TASK_SOLUTION_CODE_ANALYTICS = "task_solution_code_analytics"
        TASK_SOLUTION_CODE = "task_solution_code"

    def __init__(self, id: int = 0, unit: str = "test", task_text: str = "нет", task_solution_code_analytics: str = "нет", task_solution_code: str = "нет"):
        self.id = id
        self.unit = unit
        self.task_text = task_text
        self.task_solution_code_analytics = task_solution_code_analytics
        self.task_solution_code = task_solution_code

    @staticmethod
    def deserialize(data: Dict[str, Any]) -> 'Task':
        return Task(
            id=data.get(Task.Fields.ID),
            unit=data.get(Task.Fields.UNIT),
            task_text=data.get(Task.Fields.TASK_TEXT),
            task_solution_code_analytics=data.get(Task.Fields.TASK_SOLUTION_CODE_ANALYTICS),
            task_solution_code=data.get(Task.Fields.TASK_SOLUTION_CODE)
        )


    @staticmethod
    def load_all_tasks():
        all_tasks = []
        with open(pathlib.Path(pathlib.Path(pathlib.Path.cwd(), "tasks_base.json"))) as f:
            for row in f:
                all_tasks.append(Task.deserialize(json.loads(row)))
        return all_tasks


    @staticmethod
    def get_task_by_id(id: int) -> Union[Task, str]:
        all_tasks = Task.load_all_tasks()
        for task in all_tasks:
            if task.id == id:
                return task
        return "NO TASK WITH THAT WORD, CHECK IT"

    @staticmethod
    def find_by_word(word: str):
        all_tasks = Task.load_all_tasks()
        for task in all_tasks:
            task_words = task.task_text.split(" ")
            task_words = [w.lower() for w in task_words]
            if word in task_words:
                print(task.id, task.task_text)
